@@ -1,7 +1,7 @@
 """Contains constraint data structures and types."""
 from collections import OrderedDict
 from dataclasses import dataclass
-from typing import Any, List, Union
+from typing import Any, Callable, List, Union
 
 from apgw.types import Params
 
@@ -28,6 +28,18 @@ class Literal:
     value: str
 
 
+@dataclass(frozen=True)
+class MappedPlaceholder:
+    """Given a custom mapping to a placeholder in case you want to give a fallback,
+    coalesce, etc."""
+
+    value: Any
+    map_placeholder: Callable[[str], str]
+
+    def get_mapped_placeholder(self, placeholder: str) -> str:
+        return getattr(self, "map_placeholder")(placeholder)
+
+
 @dataclass(frozen=True)
 class GroupConstraint:
     """Represents a group of constraints."""
