@@ -41,7 +41,7 @@ class DBBase:
         """Returns True if the connection can and should be opened automatically."""
         return not self.is_open
 
-    def log(
+    async def log(
         self,
         sql: str,
         params: Optional[Params],
@@ -133,7 +133,7 @@ class DBBase:
             error = ex
             raise
         finally:
-            self.log(sql, params, time() - start, error)
+            await self.log(sql, params, time() - start, error)
 
     async def executemany(
         self, sql: Optional[str], params: Optional[List[Iterable[Any]]] = None
@@ -159,7 +159,7 @@ class DBBase:
             error = ex
             raise
         finally:
-            self.log(sql, params, time() - start, error)
+            await self.log(sql, params, time() - start, error)
 
     async def fetch(
         self, sql: Optional[str], params: Optional[Params] = None
@@ -185,7 +185,7 @@ class DBBase:
             error = ex
             raise
         finally:
-            self.log(sql, params, time() - start, error)
+            await self.log(sql, params, time() - start, error)
 
     async def fetchrow(
         self, sql: Optional[str], params: Optional[Params] = None
@@ -211,7 +211,7 @@ class DBBase:
             error = ex
             raise
         finally:
-            self.log(sql, params, time() - start, error)
+            await self.log(sql, params, time() - start, error)
 
     async def select(
         self,
@@ -436,7 +436,7 @@ class DB(DBBase):
     async def get_connection_args(self) -> ConnectionArgs:
         return self._conn_args
 
-    def log(
+    async def log(
         self, sql: str, params: Optional[Params], duration: float, error: bool
     ) -> None:
         pass
