@@ -1,7 +1,7 @@
 """Contains util methods."""
 from typing import List
 
-from apgw.constraint import BinaryConstraint, Literal
+from apgw.constraint import BinaryConstraint, Literal, MappedPlaceholder
 from apgw.types import SQL, Params
 
 
@@ -16,7 +16,7 @@ def constraint_list_to_sql(
     """Turns a list of constraints into a (sql, params) pair."""
     parts: List[str] = []
     params: Params = []
-    placeholder = offset + 1
+    placeholder_index = offset + 1
 
     for constraint in constraints:
         if constraint.value is None and handle_null:
@@ -38,9 +38,21 @@ def constraint_list_to_sql(
                     constraint.column, constraint.operator, constraint.value.value
                 )
             )
+        elif isinstance(constraint.value, MappedPlaceholder):
+            placeholder = "${}".format(placeholder_index)
+            placeholder_index += 1
+
+            parts.append(
+                "{} {} {}".format(
+                    constraint.column,
+                    constraint.operator,
+                    constraint.value.get_mapped_placeholder(placeholder),
+                )
+            )
+            params.append(constraint.value.value)
         elif isinstance(constraint.value, list):
             in_list = ", ".join(
-                generate_placeholders(len(constraint.value), placeholder)
+                generate_placeholders(len(constraint.value), placeholder_index)
             )
             parts.append(
                 "{} {} ({})".format(
@@ -50,13 +62,15 @@ def constraint_list_to_sql(
                 )
             )
             params.extend(constraint.value)
-            placeholder += len(constraint.value)
+            placeholder_index += len(constraint.value)
         else:
             parts.append(
-                "{} {} ${}".format(constraint.column, constraint.operator, placeholder)
+                "{} {} ${}".format(
+                    constraint.column, constraint.operator, placeholder_index
+                )
             )
             params.append(constraint.value)
-            placeholder += 1
+            placeholder_index += 1
 
     if paren:
         sql = joiner.join("({})".format(p) for p in parts)
